﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.ComponentModel;
using System.Windows.Forms;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;

namespace HeuristicLab.Problems.DataAnalysis.Views {
  [View("CorrelationHeatMap View")]
  [Content(typeof(ExtendedHeatMap), true)]
  public partial class CorrelationHeatMapView : ItemView {

    public new ExtendedHeatMap Content {
      get { return (ExtendedHeatMap)base.Content; }
      set { base.Content = value; }
    }

    public CorrelationHeatMapView() {
      InitializeComponent();
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.ProgressCalculation += new DataAnalysis.ExtendedHeatMap.ProgressCalculationHandler(Content_ProgressCalculation);
    }

    protected void Content_ProgressCalculation(object sender, ProgressChangedEventArgs e) {
      if (!HeatMapProgressBar.Visible && e.ProgressPercentage != HeatMapProgressBar.Maximum) {
        HeatMapProgressBar.Show();
      } else if (e.ProgressPercentage == HeatMapProgressBar.Maximum) {
        HeatMapProgressBar.Hide();
      }
      HeatMapProgressBar.Value = e.ProgressPercentage;
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      ExtendedHeatMapView.Content = Content;
      if (Content != null) {
        CorrelationCalcComboBox.DataSource = Content.CorrelationCalculators;
        PartitionComboBox.DataSource = Content.Partitions;
      }
    }

    private void CorrelationCalcComboBox_SelectedIndexChanged(object sender, System.EventArgs e) {
      CalculateHeatMap();
    }

    private void PartitionComboBox_SelectedIndexChanged(object sender, System.EventArgs e) {
      CalculateHeatMap();
    }

    private void CalculateHeatMap() {
      string calc = (string)CorrelationCalcComboBox.SelectedItem;
      string partition = (string)PartitionComboBox.SelectedItem;
      if (calc != null && partition != null) {
        Content.Recalculate(calc, partition);
        base.OnContentChanged();
      }
    }
  }
}
